


     using System;
     using System.Net;
     using System.Threading.Tasks;
     using Inetlab.MMS;
     using Inetlab.MMS.MM7;

     public class MM7ClientExample
     {
         private readonly MM7Client _client;
         public MM7ClientExample(string mmscUrl, string authId, string authSecret, string vaspid, string vasid,
             string senderAddress, string serviceCode)
         {
             //<Create>

             _client = new MM7Client(mmscUrl);

             _client.AuthId = authId;
             _client.AuthSecret = authSecret;
             _client.VASPID = vaspid;
             _client.VASID = vasid;
             _client.SenderAddress = senderAddress;
             _client.ServiceCode = serviceCode;

             //</Create>
         }

         public async Task SendMessage(string smilFilePath)
         {
             //<Submit>
             SubmitRequest req = _client.CreateSubmitRequest();

             req.Recipients.To.Add("+79171234567");

             req.MessageClass = MessageClass.Personal;
             req.DeliveryReport = true;
             req.Subject = "Test";
             req.Priority = Priorities.Normal;
             req.ChargedParty = ChargedParty.Sender;
             req.ContentHref = "/mms/mm7/mm7client";
             req.TransactionID = DateTime.Now.Ticks.ToString();

             try
             {
                 // Submit MMS Message as VASP
                 SubmitResponse resp = await _client.Submit(smilFilePath, req);
                 // Check response status
                 if (resp.Status.StatusCode == 1000)
                 {
                     Console.WriteLine("MMS message has been sent successfully");

                 }
             }
             catch (MM7Exception ex)
             {
                 Console.Error.WriteLine(ex.Message);
                 Console.Error.WriteLine(ex.Status.Details);
             }
             catch (WebException ex)
             {
                 Console.Error.WriteLine(ex.Message);
             }

             //</Submit>
         }
     }