﻿using System;
using System.IO;
using System.Threading.Tasks;
using Inetlab.MMS;
using Inetlab.MMS.MM7;

namespace CodeSamples
{
    //<Sample>
    public class MMSServerForVASPExample
    {
        private MM7Server _server;

        public MMSServerForVASPExample()
        {  
             
            _server = new MM7Server("http://localhost:9090/");
            _server.ServerMode = MM7ServerMode.VASP;
            _server.AuthScheme = AuthenticationSchemes.Basic;
            _server.Events.OnAuthentication = OnAuthentication;
            _server.Events.OnDeliverRequest = OnDeliverRequest;
        }

        public void Start()
        {
            _server.Start();
        }

        private Task<string> OnAuthentication(AuthenticationEventArgs e)
        {
            //check username
            if (e.UserName == "test")
            {
                string password = "password from db";

                // return password
                return Task.FromResult(password);
            }

            // not authenticated.
            return Task.FromResult<string>(null);
        }


        /// <summary> Raises when MMSC delivers MMS to VASP endpoint.</summary>
        private Task<DeliverResponse> OnDeliverRequest(DeliverReqEventArgs e)
        {
            //MMS received from MMSC on VASP MMS Endpoint.

            // Save all MMS message parts to the Delivered folder
            string path = Path.GetFullPath("Delivered");
            path = Path.Combine(path, e.Request.TransactionID);
            Directory.CreateDirectory(path);

            foreach (MMSPart part in e.Message.Parts)
            {
                part.Save(Path.Combine(path, part.GetFileName()));
            }

            return Task.FromResult(new DeliverResponse(e.Request));
        }
    }
    //</Sample>
}
