﻿using System;
using System.IO;
using System.Windows.Forms;

namespace MM7ClientDemo.Controls
{
    public partial class VASPActionsControl : UserControl
    {
        public VASPActionsControl()
        {
            InitializeComponent();
        }

        public void SetFilesPath(string path)
        {
            tbMMSFilePath.Text = Path.Combine(path, "waterflow.mms");
            tbSmilFilePath.Text = Path.Combine(path, @"video\video.smil");
            tbMMSImage.Text = Path.Combine(path, "waterflow_small.jpg");
        }

        public event Action<MMSFileArgs> SendMMSFile;
        public event Action<SimpleMMSArgs> SendSimpleMMS;
        public event Action<SmilMMSArgs> SendSmilMMS;

        private void bSend_Click(object sender, EventArgs e)
        {
           SendMMSFile?.Invoke(new MMSFileArgs
           {
                Recipient = tbTo.Text.Trim(),
                FilePath = Helper.GetAbsolutePath(tbMMSFilePath.Text)
           });
        }

        private void bSendSimpleMMS_Click(object sender, EventArgs e)
        {
            SendSimpleMMS?.Invoke(new SimpleMMSArgs
            {
                Recipient = tbTo2.Text.Trim(),
                Subject = tbMMSSubject.Text,
                MessageText = tbMMSText.Text,
                ImageFilePath = Helper.GetAbsolutePath(tbMMSImage.Text)
            });
        }

        private void bSendSmilMMS_Click(object sender, EventArgs e)
        {
            SendSmilMMS?.Invoke(new SmilMMSArgs
            {
                Recipient = tbSmilTo.Text.Trim(),
                Subject = tbSmilSubject.Text,
                SmilFilePath = Helper.GetAbsolutePath(tbSmilFilePath.Text)
            });
        }


        private void bOpen_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                tbMMSFilePath.Text = Helper.GetRelativePath(openFileDialog1.FileName);
            }
        }

        private void bOpenImage_Click(object sender, EventArgs e)
        {
            if (openFileDialog2.ShowDialog() == DialogResult.OK)
            {
                tbMMSImage.Text = Helper.GetRelativePath(openFileDialog2.FileName);
            }
        }

        private void bSmilSelect_Click(object sender, EventArgs e)
        {
            if (openFileDialog2.ShowDialog() == DialogResult.OK)
            {
                tbSmilFilePath.Text = Helper.GetRelativePath(openFileDialog2.FileName);
            }
        }

    
    }
}
