﻿using System;
using System.IO;
using System.Reflection;
using System.Text.RegularExpressions;

namespace MM7ClientDemo
{
    public class Helper
    {

        /// <summary>
        /// Returns current directory
        /// </summary>
        /// <returns></returns>
        public static string GetCurrentDirectory()
        {
            string loc = System.Windows.Forms.Application.StartupPath;
            if (string.IsNullOrEmpty(loc))
            {
                loc = Assembly.GetEntryAssembly().Location;
                if (loc != null && loc.Length > 0)
                {
                    loc = Path.GetDirectoryName(loc);
                }
            }
            return loc;
        }

        public static string GetRelativePath(string absoluteFilePath)
        {
            return GetRelativePath(GetCurrentDirectory(), absoluteFilePath);
        }

        /// <summary>
        /// Gets the path relative to path mainDirPath
        /// </summary>
        /// <param name="mainDirPath"></param>
        /// <param name="absoluteFilePath"></param>
        /// <returns></returns>
        public static string GetRelativePath(string mainDirPath, string absoluteFilePath)
        {
            string[]
                firstPathParts = mainDirPath.Trim(Path.DirectorySeparatorChar).Split(Path.DirectorySeparatorChar);
            string[]
                secondPathParts = absoluteFilePath.Trim(Path.DirectorySeparatorChar).Split(Path.DirectorySeparatorChar);


            int sameCounter = 0;
            for (int i = 0; i < Math.Min(firstPathParts.Length,
                secondPathParts.Length); i++)
            {
                if (
                    !firstPathParts[i].ToLower().Equals(secondPathParts[i].ToLower()))
                {
                    break;
                }
                sameCounter++;
            }


            if (sameCounter == 0)
            {
                return absoluteFilePath;
            }


            string newPath = String.Empty;
            for (int i = sameCounter; i < firstPathParts.Length; i++)
            {
                if (i > sameCounter)
                {
                    newPath += Path.DirectorySeparatorChar;
                }
                newPath += "..";
            }
            if (newPath.Length == 0)
            {
                newPath = ".";
            }
            for (int i = sameCounter; i < secondPathParts.Length; i++)
            {
                newPath += Path.DirectorySeparatorChar;
                newPath += secondPathParts[i];
            }
            return newPath;
        }

        public static string GetAbsolutePath(string relativeFilePath)
        {
            return GetAbsolutePath(GetCurrentDirectory(), relativeFilePath);
        }

        public static string GetAbsolutePath(string mainDirPath, string relativeFilePath)
        {
            if (relativeFilePath == null) return mainDirPath;

            string[]
                firstPathParts = Regex.Split(mainDirPath.TrimEnd('\\','/'), @"[\\/]");
            string[]
                secondPathParts = Regex.Split(relativeFilePath, @"[\\/]");



            if (secondPathParts[0].EndsWith(":")) return relativeFilePath;

            if (secondPathParts[0] == String.Empty)
            {
                if (secondPathParts.Length > 1 && secondPathParts[1] != String.Empty)
                {
                    return Path.Combine(firstPathParts[0] + Path.DirectorySeparatorChar, relativeFilePath.TrimStart('\\', '/'));
                }
                else
                {
                    return string.Join(Path.DirectorySeparatorChar.ToString(), secondPathParts);

                }
            }

            int firstShift = 0;
            int secondShift = 0;
            int i = 0;
            if (secondPathParts[i] == ".")
            {
                secondShift++; i++;
            }

            while (i < secondPathParts.Length && secondPathParts[i] == "..")
            {
                if (!firstPathParts[firstPathParts.Length - firstShift -1].EndsWith(":")) firstShift++; 
                
                secondShift++; i++;
            }

            string newPath = 
                string.Join(Path.DirectorySeparatorChar.ToString(), firstPathParts, 0, firstPathParts.Length - firstShift)
                + Path.DirectorySeparatorChar +
            string.Join(Path.DirectorySeparatorChar.ToString(), secondPathParts, secondShift,
                        secondPathParts.Length - secondShift);
                


            return newPath;
        }


    }

 
}
