﻿using System;
using System.Threading;
using System.Threading.Tasks;
using Inetlab.MMS;
using Inetlab.MMS.MM7;

namespace MM7ClientDemo
{
    public class MMSCActions
    {
        private readonly MM7ClientCreator _clientCreator;

        public MMSCActions(MM7ClientCreator clientCreator)
        {
            _clientCreator = clientCreator;
        }

        public async Task<GenericResponse> SendDeliveryReport(string senderAddress, string recipient, CancellationToken token = default)
        {

            MM7Client client = _clientCreator.Create();

            DeliveryReportRequest req = client.CreateDeliveryReport();
            req.TransactionID = DateTime.Now.Ticks.ToString();
            req.MessageID = Guid.NewGuid().ToString();
            req.Sender = new Address(AddressTypes.ShortCode, senderAddress);
            req.Recipient = new Address(AddressTypes.Number, recipient);

            req.MMStatus = DeliveryStatus.Retrieved;
            req.Date = DateTime.Now;

            // Submit MMS Message as VASP
            DeliveryReportResponse resp = await client.SendDeliveryReport(req, token).ConfigureAwait(false);

            return resp;

        }

        public async Task<GenericResponse> SendReadReplyReport(string senderAddress, string recipient, CancellationToken token = default)
        {



            MM7Client client = _clientCreator.Create();


            ReadReplyReportRequest req = client.CreateReadReplyReport();
            req.TransactionID = DateTime.Now.Ticks.ToString();
            req.MessageID = Guid.NewGuid().ToString();
            req.Sender = new Address(AddressTypes.ShortCode, senderAddress);
            req.Recipient = new Address(AddressTypes.Number, recipient);

            req.MMStatus = ReadStatus.Read;
            req.TimeStamp = DateTime.Now;

            // Submit MMS Message as VASP
            ReadReplyReportResponse resp = await client.SendReadReplyReport(req, token);

            return resp;

        }

    }
}