﻿using System;
using System.Windows.Forms;
using Inetlab.MMS;
using Inetlab.MMS.Logging;

namespace MM7ServerDemo
{
    public partial class MainForm : Form
    {
        MM7Server _server;
        
       

        public MainForm()
        {

            InitializeComponent();

            LogManager.SetLoggerFactory(new TextBoxLogFactory(tbServerLog, LogLevel.Verbose));

            lLicenseInfo.Text = Inetlab.MMS.LicenseManager.Status;
        }

        private void bStartMMSServer_Click(object sender, EventArgs e)
        {
            try
            {
                MM7ServerMode serverMode = rbMMSC.Checked ? MM7ServerMode.MMSC : MM7ServerMode.VASP;

                StartServer(tbMMSServerAddress.Text, serverMode);

                cbAuthSchema.Enabled = false;
                bStartMMSServer.Enabled = false;
                bStopMMSServer.Enabled = true;
                rbVASP.Enabled = rbMMSC.Enabled = false;
            }
            catch (Exception ex)
            {
                MessageBox.Show(
                    ex.Message,
                    "Server starting error",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void bStopMMSServer_Click(object sender, EventArgs e)
        {
            _server.Stop();

            bStartMMSServer.Enabled = true;
            bStopMMSServer.Enabled = false;
            cbAuthSchema.Enabled = true;
            rbVASP.Enabled = rbMMSC.Enabled = true;
        }

        /// <summary>
        /// Start MM7 Server. 
        /// </summary>
        private void StartServer(string address, MM7ServerMode mode = MM7ServerMode.VASP)
        {
            _server = new MM7Server(address);

            if (!string.IsNullOrEmpty(cbAuthSchema.Text))
            {
                _server.AuthScheme = (AuthenticationSchemes)Enum.Parse(typeof(AuthenticationSchemes), cbAuthSchema.Text, true);
            }


            _server.ServerMode = mode;
            AttachServerEvents(mode);


            // Start server
            _server.Start();
        }

        private void AttachServerEvents(MM7ServerMode mode)
        {
            if (mode == MM7ServerMode.MMSC)
            {
                _server.Events = new MMSCEvents();
            }
            else
            {
                _server.Events = new VASPEvents();
            }
        }


        private void ModeChange(object sender, EventArgs e)
        {
            _server.ServerMode = rbMMSC.Checked ? MM7ServerMode.MMSC : MM7ServerMode.VASP;

            AttachServerEvents(_server.ServerMode);
        }

 
    }
}
