﻿using System.IO;
using System.Text;
using System.Threading.Tasks;
using Inetlab.MMS;
using Inetlab.MMS.MM7;

namespace MM7ServerDemo
{
    // Server events for Value Added Service Provider
    internal class VASPEvents : MM7ServerEvents
    {
        public override Task<DeliverResponse> DeliverRequest(DeliverReqEventArgs e)
        {
            //MMS received from MMSC on VASP MMS Endpoint.

            // Save all MMS message parts to the Delivered folder
            string path = Path.GetFullPath("Delivered");
            path = Path.Combine(path, e.Request.TransactionID);
            Directory.CreateDirectory(path);

            foreach (MMSPart part in e.Message.Parts)
            {
                part.Save(Path.Combine(path, part.GetFileName()));
            }

            return Task.FromResult(new DeliverResponse(e.Request));
        }

        public override Task<DeliveryReportResponse> DeliveryReport(DeliveryReportRequestEventArgs e)
        {
            string path = Path.GetFullPath("DeliveryReports");
            Directory.CreateDirectory(path);
            string fileName = Path.Combine(path, e.Request.TransactionID);

            StringBuilder sb = new StringBuilder();
            sb.AppendLine(string.Format("MessageID: {0}", e.Request.MessageID));
            sb.AppendLine(string.Format("MMStatus: {0}", e.Request.MMStatus));
            if (e.Request.MMStatusExtension != MMStatusExtensionType.None)
            {
                sb.AppendLine(string.Format("MMStatusExtension: {0}", e.Request.MMStatusExtension));
            }
            if (!string.IsNullOrEmpty(e.Request.StatusText))
            {
                sb.AppendLine(string.Format("StatusText: {0}", e.Request.StatusText));
            }
            sb.AppendLine(string.Format("Recipient: {0}", e.Request.Recipient));
            sb.AppendLine(string.Format("Sender: {0}", e.Request.Sender));
            if (!string.IsNullOrEmpty(e.Request.ApplicID))
            {
                sb.AppendLine(string.Format("ApplicID: {0}", e.Request.ApplicID));
            }
            if (!string.IsNullOrEmpty(e.Request.ReplyApplicID))
            {
                sb.AppendLine(string.Format("ReplyApplicID: {0}", e.Request.ReplyApplicID));
            }
            if (!string.IsNullOrEmpty(e.Request.AuxApplicInfo))
            {
                sb.AppendLine(string.Format("AuxApplicInfo: {0}", e.Request.AuxApplicInfo));
            }
            if (e.Request.UACapabilities != null)
            {
                sb.AppendLine(string.Format("UACapabilities: {0}, {1}",
                    e.Request.UACapabilities.UAProf,
                    e.Request.UACapabilities.TimeStamp));
            }

            File.WriteAllText(fileName, sb.ToString());

            return Task.FromResult(new DeliveryReportResponse(e.Request));
        }


        public override Task<ReadReplyReportResponse> ReadReplyReport(ReadReplyReportRequestEventArgs e)
        {
            string path = Path.GetFullPath("ReadReplyReports");
            Directory.CreateDirectory(path);
            string fileName = Path.Combine(path, e.Request.TransactionID);

            StringBuilder sb = new StringBuilder();
            sb.AppendLine(string.Format("MessageID: {0}", e.Request.MessageID));
            sb.AppendLine(string.Format("MMStatus: {0}", e.Request.MMStatus));
            if (!string.IsNullOrEmpty(e.Request.StatusText))
            {
                sb.AppendLine(string.Format("StatusText: {0}", e.Request.StatusText));
            }
            sb.AppendLine(string.Format("Recipient: {0}", e.Request.Recipient));
            sb.AppendLine(string.Format("Sender: {0}", e.Request.Sender));
            if (!string.IsNullOrEmpty(e.Request.ApplicID))
            {
                sb.AppendLine(string.Format("ApplicID: {0}", e.Request.ApplicID));
            }
            if (!string.IsNullOrEmpty(e.Request.ReplyApplicID))
            {
                sb.AppendLine(string.Format("ReplyApplicID: {0}", e.Request.ReplyApplicID));
            }
            if (!string.IsNullOrEmpty(e.Request.AuxApplicInfo))
            {
                sb.AppendLine(string.Format("AuxApplicInfo: {0}", e.Request.AuxApplicInfo));
            }

            File.WriteAllText(fileName, sb.ToString());

            return Task.FromResult(new ReadReplyReportResponse(e.Request));
        }
    }
}