﻿using System;
using System.Collections.Specialized;
using System.IO;
using System.Security.Principal;
using System.Threading.Tasks;
using System.Web;
using Inetlab.MMS;

namespace MMSServer.ASPNET
{

    internal class TestHttpContextWrapper: IHttpContext
    {
        private readonly HttpContext _httpContext;

        public TestHttpContextWrapper(HttpContext httpContext)
        {
            _httpContext = httpContext;
            Request = new HttpRequestWrapper(httpContext.Request);
            Response = new HttpResponseWrapper(httpContext.Response);
        }

        public IPrincipal User
        {
            get
            {
                if (_httpContext != null)
                {
                    return _httpContext.User;
                }

                return null;
            }
            set
            {
                if (_httpContext != null)
                {
                    _httpContext.User = value;
                }
            }
        }

        public IHttpResponse Response { get; }


        public IHttpRequest Request { get; }
    }

    internal class HttpRequestWrapper: IHttpRequest
    {
        private readonly HttpRequest _httpRequest;
  
 
        public HttpRequestWrapper(HttpRequest httpRequest)
        {
            _httpRequest = httpRequest;
        }

        public Uri Url
        {
            get
            {
                if (_httpRequest != null)
                {
                    return _httpRequest.Url;
                }

                return null;
            }
        }

        public NameValueCollection Headers
        {
            get
            {

                if (_httpRequest != null)
                {
                    return _httpRequest.Headers;
                }

                return new NameValueCollection();
            }
        }

        public string Method
        {
            get
            {
                if (_httpRequest != null)
                {
                    return _httpRequest.HttpMethod;
                }

                return null;
            }
        }

        public string UserHostAddress
        {
            get
            {

                if (_httpRequest != null)
                {
                    return _httpRequest.UserHostAddress;
                }

                return null;
            }
        }

        public string ContentType
        {
            get
            {
                if (_httpRequest != null)
                {
                    return _httpRequest.ContentType;
                }

                return null;
            }
        }

        public long ContentLength
        {
            get
            {
                if (_httpRequest != null)
                {
                    return _httpRequest.ContentLength;
                }

                return 0;
            }
        }

        public Stream InputStream
        {
            get
            {
                if (_httpRequest != null)
                {
                    return _httpRequest.InputStream;
                }

                return null;
            }
        }

  


    }

    internal class HttpResponseWrapper: IHttpResponse
    {
        private readonly HttpResponse _httpResponse;

        public HttpResponseWrapper(HttpResponse httpResponse)
        {
            _httpResponse = httpResponse;
        }

        public int StatusCode
        {
            get { return  _httpResponse.StatusCode; }
            set { _httpResponse.StatusCode = value; }
        }

        public NameValueCollection Headers
        {
            get { return _httpResponse.Headers; }
        }

        public string ContentType
        {
            get { return _httpResponse.ContentType; }
            set { _httpResponse.ContentType = value; }
        }

        public long ContentLength
        {
            get
            {
                    string val = _httpResponse.Headers["Content-Length"];
                    if (val != null) {
                        long length;
                        if (long.TryParse(val, out length))
                        {
                            return length;
                        }
                    }

                return -1;
            }
            set
            {
                    if (value < 0)
                    {
                        if (_httpResponse.Headers["Content-Length"] != null)
                        {
                            _httpResponse.Headers.Remove("Content-Length");
                        }
                    }
                    else
                    {
                        _httpResponse.Headers["Content-Length"] = value.ToString();
                    }
            }
        }

        public Stream OutputStream
        {
            get
            {
                return _httpResponse.OutputStream;
            }
        }

        public void Close()
        {
        }

        public void AddHeader(string name, string value)
        {
             _httpResponse.AddHeader(name, value);
        }

        public Task Write(string text)
        {
            _httpResponse.Write(text);

            return Task.FromResult(0);
        }

        public void End()
        {
            _httpResponse.End();
        }
    }
}
