﻿using System;
using Inetlab.MMS.Logging;
using Microsoft.Extensions.Logging;
using LogLevel = Inetlab.MMS.Logging.LogLevel;

namespace MMSServer.ASPNETCore
{
    public class MicrosoftLogFactory : ILogFactory
    {
        private readonly ILoggerFactory _loggerFactory;

        public MicrosoftLogFactory(ILoggerFactory loggerFactory)
        {
            _loggerFactory = loggerFactory;
        }
        public ILog GetLogger(string loggerName)
        {
            return new MiscrosoftLogger(_loggerFactory.CreateLogger(loggerName));
        }


        internal class MiscrosoftLogger : ILog
        {
            private readonly ILogger _logger;

            public MiscrosoftLogger(ILogger logger)
            {
                _logger = logger;
            }

            public bool IsEnabled(LogLevel level)
            {
                return _logger.IsEnabled(ConvertLogLevel(level));
            }

            private Microsoft.Extensions.Logging.LogLevel ConvertLogLevel(LogLevel level)
            {
                switch (level)
                {
                    case LogLevel.All:
                        return Microsoft.Extensions.Logging.LogLevel.Trace;
                    case LogLevel.Verbose:
                        return Microsoft.Extensions.Logging.LogLevel.Trace;
                    case LogLevel.Debug:
                        return Microsoft.Extensions.Logging.LogLevel.Debug;
                    case LogLevel.Info:
                        return Microsoft.Extensions.Logging.LogLevel.Information;
                    case LogLevel.Warning:
                        return Microsoft.Extensions.Logging.LogLevel.Warning;
                    case LogLevel.Error:
                        return Microsoft.Extensions.Logging.LogLevel.Error;
                    case LogLevel.Fatal:
                        return Microsoft.Extensions.Logging.LogLevel.Critical;
                    case LogLevel.Off:
                        return Microsoft.Extensions.Logging.LogLevel.None;
                    default:
                        throw new ArgumentOutOfRangeException(nameof(level), level, null);
                }
            }

            public void Write(LogLevel level, string message, Exception ex, params object[] args)
            {
                _logger.Log(ConvertLogLevel(level), new EventId(0), message, ex, args);
            }
        }
    }
}