﻿using System;
using System.Threading.Tasks;
using Inetlab.MMS;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Http.Extensions;
using Microsoft.AspNetCore.Server.Kestrel.Core;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;

namespace MMSServer.ASPNETCore
{
    public class Startup
    {
        public Startup(ILoggerFactory loggerFactory)
        {
            
            Inetlab.MMS.Logging.LogManager.SetLoggerFactory(new MicrosoftLogFactory(loggerFactory));

            // INSTALL LICENSE FILE
            // ====================
            // Add Inetlab.MMS.MM7.license file to the project and change "Build Action" of the file to "Embedded Resource".
            //
            // bool valid = Inetlab.MMS.LicenseManager.SetLicense(typeof(Program).Assembly.GetManifestResourceStream(typeof(Program), "Inetlab.MMS.MM7.license"));

        }

        // This method gets called by the runtime. Use this method to add services to the container.
        // For more information on how to configure your application, visit https://go.microsoft.com/fwlink/?LinkID=398940
        public void ConfigureServices(IServiceCollection services)
        { 
            services.Configure<KestrelServerOptions>(options =>
            {
                options.AllowSynchronousIO = true;
            });

            // If using IIS:
            services.Configure<IISServerOptions>(options =>
            {
                options.AllowSynchronousIO = true;
            });
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseMM7Endpoint("/mms", new TestMM7ServerEvents());


            app.Map("", IndexHandler);
        }

        private static void IndexHandler(IApplicationBuilder app)
        {
            app.Use(async (context, next) =>
            {
                Uri mmsUrl = new UriBuilder(context.Request.Scheme, context.Request.Host.Host,
                    context.Request.Host.Port.GetValueOrDefault(), "mms").Uri;

                await context.Response.WriteAsync($@"
 <html xmlns=""http://www.w3.org/1999/xhtml"">
    <body>
    <div>
       {LicenseManager.Status}
    </div>
    <div>
       Try to send MMS message with MM7ClientDemo application to URL <b>{mmsUrl}</b>
    </div>
    </body>
 </html>");
            });

        }
    }

}
